@@ -23,6 +23,7 @@
 #include "e-cal-data-model.h"
 
 #include <libical/icaltime.h>
+#include <goa/goa.h>
 
 G_BEGIN_DECLS
 
@@ -49,8 +50,10 @@ struct _GcalManagerClass
   void (*source_activated)  (GcalManager *manager, ESource *source, gboolean active);
   void (*source_added)  (GcalManager *manager, ESource *source, gboolean enabled);
   void (*source_removed)  (GcalManager *manager, ESource *source);
+  void (*source_enabled)  (GcalManager *manager, ESource *source, gboolean enabled);
   void (*load_completed)  (GcalManager *manager);
   void (*query_completed) (GcalManager *manager);
+  void (*goa_client_ready) (GcalManager *manager, GoaClient *client);
 };
 
 typedef struct
@@ -63,12 +66,18 @@ GType          gcal_manager_get_type                (void);
 
 GcalManager*   gcal_manager_new_with_settings       (GSettings          *settings);
 
+ESource*       gcal_manager_get_source              (GcalManager        *manager,
+                                                     const gchar        *uid);
+
 GList*         gcal_manager_get_sources             (GcalManager        *manager);
 
 GList*         gcal_manager_get_sources_connected   (GcalManager        *manager);
 
 ESource*       gcal_manager_get_default_source      (GcalManager        *manager);
 
+void           gcal_manager_set_default_source      (GcalManager        *manager,
+                                                     ESource            *source);
+
 icaltimezone*  gcal_manager_get_system_timezone     (GcalManager        *manager);
 
 void           gcal_manager_setup_shell_search      (GcalManager             *manager,
@@ -99,6 +108,10 @@ void           gcal_manager_set_search_subscriber   (GcalManager        *manager
 void           gcal_manager_set_query               (GcalManager        *manager,
                                                      const gchar        *query);
 
+gchar*         gcal_manager_query_client_data       (GcalManager        *manager,
+                                                     ESource            *source,
+                                                     const gchar        *field);
+
 gchar*         gcal_manager_add_source              (GcalManager        *manager,
                                                      const gchar        *name,
                                                      const gchar        *backend,
@@ -110,6 +123,9 @@ void           gcal_manager_enable_source           (GcalManager        *manager
 void           gcal_manager_disable_source          (GcalManager        *manager,
                                                      ESource            *source);
 
+void           gcal_manager_save_source             (GcalManager        *manager,
+                                                     ESource            *source);
+
 gboolean       gcal_manager_source_enabled          (GcalManager        *manager,
                                                      ESource            *source);
 
@@ -148,6 +164,10 @@ gboolean       gcal_manager_load_completed          (GcalManager        *manager
 GcalEventData* gcal_manager_get_event_from_shell_search (GcalManager        *manager,
                                                          const gchar        *uuid);
 
+gboolean       gcal_manager_is_goa_client_ready    (GcalManager        *manager);
+
+GoaClient*     gcal_manager_get_goa_client         (GcalManager        *manager);
+
 G_END_DECLS
 
 #endif /* __GCAL_MANAGER_H__ */
